summaryrefslogtreecommitdiff
path: root/chromium/content/common/service_worker/service_worker_types.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/content/common/service_worker/service_worker_types.h')
-rw-r--r--chromium/content/common/service_worker/service_worker_types.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/chromium/content/common/service_worker/service_worker_types.h b/chromium/content/common/service_worker/service_worker_types.h
index bf4983a15ce..15b83155507 100644
--- a/chromium/content/common/service_worker/service_worker_types.h
+++ b/chromium/content/common/service_worker/service_worker_types.h
@@ -90,10 +90,14 @@ struct CONTENT_EXPORT ServiceWorkerFetchRequest {
ServiceWorkerFetchRequest& operator=(const ServiceWorkerFetchRequest& other);
~ServiceWorkerFetchRequest();
size_t EstimatedStructSize();
+ std::string Serialize() const;
static blink::mojom::FetchCacheMode GetCacheModeFromLoadFlags(int load_flags);
+ static ServiceWorkerFetchRequest ParseFromString(
+ const std::string& serialized);
- // Be sure to update EstimatedStructSize() when adding members.
+ // Be sure to update EstimatedStructSize(), Serialize(), and ParseFromString()
+ // when adding members.
network::mojom::FetchRequestMode mode =
network::mojom::FetchRequestMode::kNoCORS;
bool is_main_resource_load = false;